summaryrefslogtreecommitdiff
path: root/lib/gnutls_session.c
diff options
context:
space:
mode:
authorNikos Mavrogiannopoulos <nmav@gnutls.org>2001-12-05 17:25:44 +0000
committerNikos Mavrogiannopoulos <nmav@gnutls.org>2001-12-05 17:25:44 +0000
commitc393fd8a48c256b7d7cd087190a66dbc87c048e6 (patch)
tree64bca7e167b543c4af0e1cab92937a274e58deb0 /lib/gnutls_session.c
parentc3bb0dca4238ef75893b00d73a883a8b3f2c7ce3 (diff)
downloadgnutls-c393fd8a48c256b7d7cd087190a66dbc87c048e6.tar.gz
Changes in function names concerning _db_ handling and _session_ handling.
Diffstat (limited to 'lib/gnutls_session.c')
-rw-r--r--lib/gnutls_session.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/lib/gnutls_session.c b/lib/gnutls_session.c
index 8e98641e60..43cca3e1ab 100644
--- a/lib/gnutls_session.c
+++ b/lib/gnutls_session.c
@@ -25,19 +25,19 @@
#define SESSION_SIZE _gnutls_session_size( state)
/**
* gnutls_get_current_session - Returns all session parameters.
* @state: is a &GNUTLS_STATE structure.
* @session: is a pointer to space to hold the session.
* @session_size: is the session's size, or it will be set by the function.
*
* Returns all session parameters - in order to support resuming.
* The client should call this - and keep the returned session - if he wants to
* resume that current version later by calling gnutls_set_current_session()
* This function must be called after a successful handshake.
*
* Resuming sessions is really useful and speedups connections after a succesful one.
**/
-int gnutls_get_current_session( GNUTLS_STATE state, opaque* session, int *session_size) {
+int gnutls_session_get_data( GNUTLS_STATE state, opaque* session, int *session_size) {
gnutls_datum psession;
int ret;
@@ -67,7 +67,7 @@ int gnutls_get_current_session( GNUTLS_STATE state, opaque* session, int *sessio
/**
* gnutls_get_current_session_id - Returns session id.
* @state: is a &GNUTLS_STATE structure.
* @session: is a pointer to space to hold the session id.
* @session_size: is the session id's size, or it will be set by the function.
@@ -79,7 +79,7 @@ int gnutls_get_current_session( GNUTLS_STATE state, opaque* session, int *sessio
* Session id is some data set by the server, that identify the current session.
* In TLS 1.0 session id should not be more than 32 bytes.
**/
-int gnutls_get_current_session_id( GNUTLS_STATE state, void* session, int *session_size) {
+int gnutls_session_get_id( GNUTLS_STATE state, void* session, int *session_size) {
*session_size = state->security_parameters.session_id_size;
@@ -93,19 +93,19 @@ int gnutls_get_current_session_id( GNUTLS_STATE state, void* session, int *sessi
}
/**
* gnutls_set_current_session - Sets all session parameters
* @state: is a &GNUTLS_STATE structure.
* @session: is a pointer to space to hold the session.
* @session_size: is the session's size
*
* Sets all session parameters - in order to support resuming
- * session must be the one returned by gnutls_get_current_session();
+ * session must be the one returned by gnutls_session_get_data();
* This function should be called before gnutls_handshake().
* Keep in mind that session resuming is advisory. The server may
* choose not to resume the session, thus a full handshake will be
* performed.
**/
-int gnutls_set_current_session( GNUTLS_STATE state, opaque* session, int session_size) {
+int gnutls_session_set_data( GNUTLS_STATE state, opaque* session, int session_size) {
int ret;
gnutls_datum psession = { session, session_size };
@@ -25,19 +25,19 @@
#define SESSION_SIZE _gnutls_session_size( state)
/**
- * gnutls_get_current_session - Returns all session parameters.
+ * gnutls_session_get_data - Returns all session parameters.
* @state: is a &GNUTLS_STATE structure.
* @session: is a pointer to space to hold the session.
@@ -25,19 +25,19 @@
* Returns all session parameters - in order to support resuming.
* The client should call this - and keep the returned session - if he wants to
- * resume that current version later by calling gnutls_set_current_session()
+ * resume that current version later by calling gnutls_session_set_data()
* This function must be called after a successful handshake.
*
@@ -67,7 +67,7 @@ int gnutls_get_current_session( GNUTLS_STATE state, opaque* session, int *sessio
/**
- * gnutls_get_current_session_id - Returns session id.
+ * gnutls_session_get_id - Returns session id.
* @state: is a &GNUTLS_STATE structure.
* @session: is a pointer to space to hold the session id.
@@ -93,19 +93,19 @@ int gnutls_get_current_session_id( GNUTLS_STATE state, void* session, int *sessi
}
/**
- * gnutls_set_current_session - Sets all session parameters
+ * gnutls_session_set_data - Sets all session parameters
* @state: is a &GNUTLS_STATE structure.
* @session: is a pointer to space to hold the session.